# django-vega-admin

[![Build Status](https://api.travis-ci.com/moshthepitt/django-vega-admin.svg?branch=master)](https://travis-ci.com/moshthepitt/django-vega-admin)

Django VegaAdmin - simple and fast automated CRUD for any Django model

## Contribution

- Clone this repo
- Run: `pip install -r requirements/dev.txt`
- Run: `pre-commit install`

## Tests

- Clone this repo
- Run: `tox`
